==> huaweicloudsdkosm-3.1.51-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/im_unread_v2.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ImUnreadV2:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'status': 'int',
        'incident_id': 'str',
        'unread_num': 'int'
    }

    attribute_map = {
        'status': 'status',
        'incident_id': 'incident_id',
        'unread_num': 'unread_num'
    }

    def __init__(self, status=None, incident_id=None, unread_num=None):
        """ImUnreadV2

        The model defined in huaweicloud sdk

        :param status: 状态
        :type status: int
        :param incident_id: 工单id
        :type incident_id: str
        :param unread_num: 未读数量
        :type unread_num: int
        """
        
        

        self._status = None
        self._incident_id = None
        self._unread_num = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if incident_id is not None:
            self.incident_id = incident_id
        if unread_num is not None:
            self.unread_num = unread_num

    @property
    def status(self):
        """Gets the status of this ImUnreadV2.

        状态

        :return: The status of this ImUnreadV2.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ImUnreadV2.

        状态

        :param status: The status of this ImUnreadV2.
        :type status: int
        """
        self._status = status

    @property
    def incident_id(self):
        """Gets the incident_id of this ImUnreadV2.

        工单id

        :return: The incident_id of this ImUnreadV2.
        :rtype: str
        """
        return self._incident_id

    @incident_id.setter
    def incident_id(self, incident_id):
        """Sets the incident_id of this ImUnreadV2.

        工单id

        :param incident_id: The incident_id of this ImUnreadV2.
        :type incident_id: str
        """
        self._incident_id = incident_id

    @property
    def unread_num(self):
        """Gets the unread_num of this ImUnreadV2.

        未读数量

        :return: The unread_num of this ImUnreadV2.
        :rtype: int
        """
        return self._unread_num

    @unread_num.setter
    def unread_num(self, unread_num):
        """Sets the unread_num of this ImUnreadV2.

        未读数量

        :param unread_num: The unread_num of this ImUnreadV2.
        :type unread_num: int
        """
        self._unread_num = unread_num

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImUnreadV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkosm-3.1.145-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/im_unread_v2.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ImUnreadV2:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'status': 'int',
        'incident_id': 'str',
        'unread_num': 'int'
    }

    attribute_map = {
        'status': 'status',
        'incident_id': 'incident_id',
        'unread_num': 'unread_num'
    }

    def __init__(self, status=None, incident_id=None, unread_num=None):
        r"""ImUnreadV2

        The model defined in huaweicloud sdk

        :param status: 状态
        :type status: int
        :param incident_id: 工单id
        :type incident_id: str
        :param unread_num: 未读数量
        :type unread_num: int
        """
        
        

        self._status = None
        self._incident_id = None
        self._unread_num = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if incident_id is not None:
            self.incident_id = incident_id
        if unread_num is not None:
            self.unread_num = unread_num

    @property
    def status(self):
        r"""Gets the status of this ImUnreadV2.

        状态

        :return: The status of this ImUnreadV2.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        r"""Sets the status of this ImUnreadV2.

        状态

        :param status: The status of this ImUnreadV2.
        :type status: int
        """
        self._status = status

    @property
    def incident_id(self):
        r"""Gets the incident_id of this ImUnreadV2.

        工单id

        :return: The incident_id of this ImUnreadV2.
        :rtype: str
        """
        return self._incident_id

    @incident_id.setter
    def incident_id(self, incident_id):
        r"""Sets the incident_id of this ImUnreadV2.

        工单id

        :param incident_id: The incident_id of this ImUnreadV2.
        :type incident_id: str
        """
        self._incident_id = incident_id

    @property
    def unread_num(self):
        r"""Gets the unread_num of this ImUnreadV2.

        未读数量

        :return: The unread_num of this ImUnreadV2.
        :rtype: int
        """
        return self._unread_num

    @unread_num.setter
    def unread_num(self, unread_num):
        r"""Sets the unread_num of this ImUnreadV2.

        未读数量

        :param unread_num: The unread_num of this ImUnreadV2.
        :type unread_num: int
        """
        self._unread_num = unread_num

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImUnreadV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
